@@ -25,7 +25,10 @@ if lib_checker.installed_libs[SCIKIT]:
     import sklearn
     if sklearn.__version__ == '0.23.0':
         raise Exception(' Scikit learn version 0.23.0 is not supported, Please downgrade scikit version to a lower version and re-try. ')
-    from sklearn.externals import joblib
+    try:
+        from sklearn.externals import joblib
+    except ImportError:
+        import joblib
 
 logger = logging.getLogger('ScikitPipelineReader')
 
