@@ -32,6 +32,7 @@ class SwSpec(WMLResource):
         if self._client.WSD_20:
             self.software_spec_list = {
                                 "default_py3.6": "0062b8c9-8b7d-44a0-a9b9-46c416adcbd9",
+                                "default_py3.7": "e4429883-c883-42b6-87a8-f419d64088cd",
                                 "scikit-learn_0.20-py3.6": "09c5a1d0-9c1e-4473-a344-eb7b665ff687",
                                 "ai-function_0.1-py3.6": "0cdb0f1e-5376-4f4d-92dd-da3b69aa9bda",
                                 "shiny-r3.6": "0e6e79df-875e-4f24-8ae9-62dcc2148306",
@@ -61,7 +62,10 @@ class SwSpec(WMLResource):
                                 "caffe-ibm_1.0-py3.6":  "8d863266-7927-4d1e-97d7-56a7f4c0a19b",
                                 "spss-modeler_17.1":  "902d0051-84bd-4af6-ab6b-8f6aa6fdeabb",
                                 "do_12.10":  "9100fd72-8159-4eb9-8a0b-a87e12eefa36",
-                                "hybrid_0.2":  "9b3f9040-9cee-4ead-8d7a-780600f542f7"}
+                                "hybrid_0.2":  "9b3f9040-9cee-4ead-8d7a-780600f542f7",
+                                "tensorflow_2.1-py3.7": "c4032338-2a40-500a-beef-b01ab2667e27",
+                                "pytorch-onnx_1.3-py3.7": "8d5d8a87-a912-54cf-81ec-3914adaa988d"
+                                }
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self,sw_spec_uid=None):
@@ -133,6 +137,7 @@ class SwSpec(WMLResource):
                  >>> }
 
         """
+        WMLResource._chk_and_block_create_update_for_python36(self)
         if self._client.WSD_20:
             raise WMLClientError(u'store() API is not supported in Watson Studio Desktop.')
 
@@ -363,6 +368,7 @@ class SwSpec(WMLResource):
                 >>> client.software_specifications.add_package_extension(sw_spec_uid, pkg_extn_id)
 
         """
+        WMLResource._chk_and_block_create_update_for_python36(self)
         if self._client.WSD_20:
             raise WMLClientError(u'package extension APIs are not supported in Watson Studio Desktop.')
 
