@@ -60,9 +60,18 @@ class TestWMLClientWithScikitLearn(unittest.TestCase):
 
         self.client.repository.ModelMetaNames.show()
 
+        # swspec_id = self.client.software_specifications.get_uid_by_name("scikit-learn_0.23-py3.7")
+        self.client.software_specifications.list()
+        self.client.runtimes.list(pre_defined=True, limit=200)
+
+        # print("swspec_id" + swspec_id)
+
         model_props = {self.client.repository.ModelMetaNames.NAME: "ScikitModel",
-            self.client.repository.ModelMetaNames.TYPE: "scikit-learn_0.20",
-            self.client.repository.ModelMetaNames.RUNTIME_UID: "scikit-learn_0.20-py3.6"
+            # self.client.repository.ModelMetaNames.TYPE: "scikit-learn_0.20",
+                       self.client.repository.ModelMetaNames.TYPE: "scikit-learn_0.23",
+            # self.client.repository.ModelMetaNames.RUNTIME_UID: "scikit-learn_0.20-py3.6"
+            #            self.client.repository.ModelMetaNames.SOFTWARE_SPEC_UID: swspec_id
+                       self.client.repository.ModelMetaNames.RUNTIME_UID: "scikit-learn_0.23-py3.7"
                        }
         published_model_details = self.client.repository.store_model(model=model_data['model'], meta_props=model_props, training_data=model_data['training_data'], training_target=model_data['training_target'])
         TestWMLClientWithScikitLearn.model_uid = self.client.repository.get_model_uid(published_model_details)
@@ -72,15 +81,15 @@ class TestWMLClientWithScikitLearn(unittest.TestCase):
         self.assertIsNotNone(TestWMLClientWithScikitLearn.model_uid)
         self.assertIsNotNone(TestWMLClientWithScikitLearn.model_url)
 
-        model_path = os.path.join(os.getcwd(), 'artifacts', 'scikit_xgboost_model.tar.gz')
-        print("Test update model")
-
-        updated_model_props = {self.client.repository.ModelMetaNames.NAME: "Updated ScikitModel"
-                               }
-        updated_published_model_details = self.client.repository.update_model(TestWMLClientWithScikitLearn.model_uid,
-                                                                              updated_meta_props=updated_model_props,
-                                                                              update_model=model_path)
-        print(updated_published_model_details)
+        # model_path = os.path.join(os.getcwd(), 'artifacts', 'scikit_xgboost_model.tar.gz')
+        # print("Test update model")
+        #
+        # updated_model_props = {self.client.repository.ModelMetaNames.NAME: "Updated ScikitModel"
+        #                        }
+        # updated_published_model_details = self.client.repository.update_model(TestWMLClientWithScikitLearn.model_uid,
+        #                                                                       updated_meta_props=updated_model_props,
+        #                                                                       update_model=model_path)
+        # print(updated_published_model_details)
 
 
     # def test_03_download_model(self):
