@@ -358,11 +358,11 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_04_deployment_setup_and_preparation(self):
         if is_cp4d():
-            TestAutoAIRemote.service = WebService(wml_credentials=self.wml_credentials.copy(),
-                                                  project_id=self.project_id,
-                                                  space_id=self.space_id)
+            TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
+                                                  source_project_id=self.project_id,
+                                                  source_space_id=self.space_id)
         else:
-            TestAutoAIRemote.service = WebService(wml_credentials=self.wml_credentials)
+            TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials)
 
         delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
 
