@@ -14,6 +14,7 @@ from watson_machine_learning_client.utils.log_util import get_logger
 from watson_machine_learning_client.utils import get_type_of_details, STR_TYPE, str_type_conv
 import urllib.parse
 import os
+import sys
 
 class WMLResource:
     def __init__(self, name, client):
@@ -757,3 +758,11 @@ class WMLResource:
 
         return "success"
 
+    def _chk_and_block_create_update_for_python36(self):
+        pass
+        # if (3 == sys.version_info.major) and (6 == sys.version_info.minor):
+        #     if not self._client.ICP and not self._client.WSD:
+        #         raise WMLClientError("Action not allowed!! Python 3.6 framework is deprecated and will be removed on Jan 20th, 2021."
+        #               "It will be read-only mode starting Nov 20th, 2020. i.e you won't be able to create or update new assets and deployment using this client."
+        #               "Use Python 3.7 instead. For details, see https://dataplatform.cloud.ibm.com/docs/content/wsj/analyze-data/pm_service_supported_frameworks.html")
+
